<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Form for downloading a processed a data dump.
 *
 * @package     local_aatplugin
 * @copyright   2024 Joseph Larochelle <larochellejo@hotmail.com>, Richard Jacklin <rijacklin1@gmail.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace local_aatplugin\form;

defined('MOODLE_INTERNAL') || die();

use renderable;
use renderer_base;
use templatable;

class download_form implements renderable, templatable {
    /**
     * Filename of generated SQL data dump.
     * @var string
     */
	private $file_name;

    /**
     * ID of data_dump task.
     * @var int
     */
	private $item_id;

    /**
     * Download URL for dump file.
     * @var int
     */
	private $download_url;

    /**
     * Constructor for the download_form class.
     *
     * @param int $item_id ID of the data_dump task
     * @param string $file_name Filename of SQL data dump file
     */
    public function __construct($item_id, $file_name, $download_url) {
		$this->item_id = $item_id;
		$this->file_name = $file_name;
		$this->download_url = $download_url;
    }

	/**
	 * Export download form data to mustache template for proper output.
	 *
	 * @param renderer_base $output
	 *
	 * @return array Data ready for use in a mustache template
	 */
	public function export_for_template(renderer_base $output) {
		return [
			'item_id' => $this->item_id,
			'file_name' => $this->file_name,
			'download_url' => $this->download_url,
			'index' => new \moodle_url('/local/aatplugin/index.php')
		];
	}
}
