<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Scheduled Task for cleaning up temporary files generated by local_aatplugin.
 *
 * @package     local_aatplugin
 * @copyright   2024 Joseph Larochelle <larochellejo@hotmail.com>, Richard Jacklin <rijacklin1@gmail.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace local_aatplugin\task;

defined('MOODLE_INTERNAL') || die();

class cleanup_temp_dump_files extends \core\task\scheduled_task {
	/**
     * Get the name of the task.
     *
     * @return string
     */
    public function get_name() {
        return get_string('task_cleanup_temp_files', 'local_aatplugin');
    }

	/**
     * Return the task's default configuration.
     * These defaults can be changed by administrators in the Scheduled tasks interface.
     *
     * @return array
     */
    public function get_default_configuration() {
        return [
            'disabled' => false,
            'minute' => '0',     // At midnight
            'hour' => '0',       // At midnight
            'day' => '*',        // Every day
            'dayofweek' => '*',  // Every day of week
            'month' => '*'       // Every month
        ];
    }

	/**
     * Execute the task
     */
    public function execute() {
        global $DB;
        
        $fs = get_file_storage();
        $context = \context_system::instance();
        
        $files = $fs->get_area_files($context->id, 'local_aatplugin', 'temp');
        $deleted = 0;
        
        foreach ($files as $file) {
            if ($file->get_timecreated() < (time() - HOURSECS)) {
                $file->delete();
                $deleted++;
            }
        }
        
		debugging(get_string('cleanup_task_complete', 'local_aatplugin', $deleted));
	}
}
