<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Main plugin file
 * @package     local_aatplugin
 * @copyright   2024 Joseph Larochelle <larochellejo@hotmail.com>, Richard Jacklin <rijacklin1@gmail.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once('../../config.php');

require_once($CFG->dirroot . '/lib/setuplib.php');
require_once($CFG->libdir . '/formslib.php');
require_once($CFG->dirroot . '/local/aatplugin/classes/file_handler.php');
require_once($CFG->dirroot . '/local/aatplugin/classes/form/dump_form.php');
require_once($CFG->dirroot . '/local/aatplugin/classes/form/download_form.php');
require_once($CFG->dirroot . '/local/aatplugin/classes/task/data_dump.php');

// Set up the page context and properties.
global $PAGE, $SITE;
$context = \context_system::instance();
$PAGE->set_context($context);
$PAGE->set_url(new \moodle_url('/local/aatplugin/index.php'));
$PAGE->set_pagelayout('standard');
$PAGE->set_title($SITE->fullname);
$PAGE->set_heading(get_string('pluginname', 'local_aatplugin'));
require_login();

$renderer = $PAGE->get_renderer('local_aatplugin');

// Handle refresh attempts for pending files
$retry = optional_param('retry', 0, PARAM_INT);
$item_id = optional_param('item_id', 0, PARAM_INT);
$file_name = optional_param('file_name', '', PARAM_TEXT);

if ($retry && $item_id && $file_name) {
    $form = new \local_aatplugin\form\dump_form(true, $item_id, $file_name);
} else {
    $form = new \local_aatplugin\form\dump_form();
}

echo $renderer->header();

if ($form->is_cancelled()) {
    redirect(new \moodle_url('/local/aatplugin/index.php'));
} else if ($fromform = $form->get_data()) {
    if (!empty($fromform->selected_courses)) {
        $export = local_aatplugin_generate_and_queue_export($fromform->selected_courses);
        $file_name = $export['filename'];
        $item_id = $export['itemid'];

        $form = new \local_aatplugin\form\dump_form(true, $item_id, $file_name);
        echo $renderer->render_dump_form($form);
    } else if (!empty($fromform->refresh)) {
		redirect(new \moodle_url(
			'/local/aatplugin/index.php',
			['retry' => 1, 'item_id' => $fromform->item_id, 'file_name' => $fromform->file_name]
		));
    }
} else {
    echo $renderer->render_dump_form($form);
}

echo $renderer->footer();
